@@ -15,7 +15,7 @@ Usage::
     describe_load_balancers_paginator: DescribeLoadBalancersPaginator = client.get_paginator("describe_load_balancers")
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Generator, List, TYPE_CHECKING
+from typing import Iterator, List, TYPE_CHECKING
 from botocore.paginate import Paginator as Boto3Paginator
 from mypy_boto3_elb.type_defs import (
     DescribeAccessPointsOutputTypeDef,
@@ -34,7 +34,7 @@ class DescribeAccountLimitsPaginator(Boto3Paginator):
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[DescribeAccountLimitsOutputTypeDef, None, None]:
+    ) -> Iterator[DescribeAccountLimitsOutputTypeDef]:
         """
         [DescribeAccountLimits.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeAccountLimits.paginate)
         """
@@ -47,7 +47,7 @@ class DescribeLoadBalancersPaginator(Boto3Paginator):
 
     def paginate(
         self, LoadBalancerNames: List[str] = None, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Generator[DescribeAccessPointsOutputTypeDef, None, None]:
+    ) -> Iterator[DescribeAccessPointsOutputTypeDef]:
         """
         [DescribeLoadBalancers.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.14/reference/services/elb.html#ElasticLoadBalancing.Paginator.DescribeLoadBalancers.paginate)
         """
